@@ -3,7 +3,7 @@
 // Purpose:     Burn dialog
 // Author:      Alex Thuering
 // Created:	23.03.2003
-// RCS-ID:      $Id: BurnDlg.cpp,v 1.26 2010/02/22 22:42:26 ntalex Exp $
+// RCS-ID:      $Id: BurnDlg.cpp,v 1.27 2010/04/05 16:22:43 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -130,9 +130,7 @@ void BurnDlg::set_properties() {
 			wxString cmd = scanCmd;
 			cmd.Replace(wxT("$DEVICE"), devices[i]);
 #ifdef __WXMSW__
-			cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + _T("..") +
-			wxString(wxFILE_SEP_PATH) + _T("dvdauthor") +
-			wxString(wxFILE_SEP_PATH) + cmd;
+			cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + cmd;
 #endif
 			wxArrayString output;
 			wxExecute(cmd, output, wxEXEC_SYNC | wxEXEC_NODISABLE);
@@ -416,7 +414,7 @@ void BurnDlg::OnOk(wxCommandEvent& event) {
 		}
 #ifdef __WXMSW__
 		if (device.Find(wxT(':')) != 1 || device.length()> 3
-				|| device.length() == 3 && device.GetChar(2) != wxT('\\')) {
+				|| (device.length() == 3 && device.GetChar(2) != wxT('\\'))) {
 			wxMessageBox(_("Invalid device name"), _("Burn"), wxOK|wxICON_ERROR, this);
 			return;
 		}
