@@ -3,7 +3,7 @@
 // Purpose:     Configuration
 // Author:      Alex Thuering
 // Created:     27.03.2003
-// RCS-ID:      $Id: Config.h,v 1.60 2010/01/19 22:30:22 ntalex Exp $
+// RCS-ID:      $Id: Config.h,v 1.61 2010/04/03 21:47:01 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -23,6 +23,7 @@ const int DEF_DISC_CAPACITY		= 0;
 const int DEF_VIDEO_FORMAT		= 2;
 const int DEF_AUDIO_FORMAT		= 3;
 const wxString DEF_AUDIO_LANG	= wxT("EN");
+const wxString DEF_SUBTITLE_LANG= wxT("EN");
 const int DEF_SPECT_RATIO		= 1;
 const int DEF_CHAPTER_LENGTH	= 10;
 const wxString DEF_BUTTON		= wxT("frame.xml");
@@ -111,6 +112,7 @@ public:
 	CONFIG_PROP_INT(DefVideoFormat, _T("Interface/DefVideoFormat"), DEF_VIDEO_FORMAT)
 	CONFIG_PROP_INT(DefAudioFormat, _T("Interface/DefAudioFormat"), DEF_AUDIO_FORMAT)
 	CONFIG_PROP(DefAudioLanguage, _T("Interface/DefAudioLanguage"), DEF_AUDIO_LANG)
+	CONFIG_PROP(DefSubtitleLanguage, _T("Interface/DefSubtitleLanguage"), DEF_SUBTITLE_LANG)
 	CONFIG_PROP_INT(DefAspectRatio, _T("Interface/DefAspectRatio"), DEF_SPECT_RATIO)
 	CONFIG_PROP_INT(DefChapterLength, _T("Interface/DefChapterLength"), DEF_CHAPTER_LENGTH)
 	CONFIG_PROP(DefButton, _T("Interface/DefButton"), DEF_BUTTON)
