@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Structure (Titles/Menus)
 // Author:      Alex Thuering
 // Created:	29.01.2003
-// RCS-ID:      $Id: DVD.cpp,v 1.74 2010/03/16 20:59:26 ntalex Exp $
+// RCS-ID:      $Id: DVD.cpp,v 1.80 2010/05/22 14:12:36 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -12,6 +12,7 @@
 #include "Menu.h"
 #include "Cache.h"
 #include "Config.h"
+#include "SubtitlePropDlg.h"
 #include <wx/file.h>
 #include <wx/filename.h>
 #include <wx/tokenzr.h>
@@ -27,11 +28,11 @@
 
 TextSub::TextSub(wxString filename) {
 	m_filename = filename;
-	m_characterSet = wxT("ISO8859-1");
-	m_font = wxT("arial.ttf");
+	m_characterSet = wxT("ISO-8859-1");
+	m_fontFamily = wxT("Arial");
+	m_fontStyle = wxT("Regular");
 	m_fontSize = 28;
-	m_hAlignment = wxT("left");
-	m_vAlignment = wxT("bottom");
+	m_alignment = (wxAlignment) (wxALIGN_CENTER_HORIZONTAL | wxALIGN_BOTTOM);
 	m_leftMargin = 60;
 	m_rightMargin = 60;
 	m_topMargin = 20;
@@ -42,20 +43,36 @@ TextSub::TextSub(wxString filename) {
 	m_movieHeight = 574;
 }
 
+wxString TextSub::GetFontFile() {
+	return SubtitlePropDlg::GetFontMap()[m_fontFamily][m_fontStyle];
+}
+
 wxSvgXmlNode* TextSub::GetXML(DVDFileType type) {
 	wxSvgXmlNode* textsubNode = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, _T("textsub"));
 	TextSub* defaults = new TextSub(wxT(""));
 	textsubNode->AddProperty(_T("filename"), m_filename);
 	if (m_characterSet != defaults->m_characterSet)
 		textsubNode->AddProperty(_T("characterset"), m_characterSet);
-	if (m_font != defaults->m_font) // || type == DVDAUTHOR_XML
-		textsubNode->AddProperty(_T("font"), m_font);
+	if (type == DVDAUTHOR_XML) {
+		if (GetFontFile().length() > 0)
+			textsubNode->AddProperty(wxT("font"), GetFontFile());
+	} else {
+		if (m_fontFamily != defaults->m_fontFamily)
+			textsubNode->AddProperty(wxT("fontFamily"), m_fontFamily);
+		if (m_fontStyle != defaults->m_fontStyle)
+			textsubNode->AddProperty(wxT("fontStyle"), m_fontStyle);
+	}
 	if (m_fontSize != defaults->m_fontSize)
 		textsubNode->AddProperty(_T("fontsize"), wxString::Format(wxT("%g"), m_fontSize));
-	if (m_hAlignment != defaults->m_hAlignment)
-		textsubNode->AddProperty(_T("horizontal-alignment"), m_hAlignment);
-	if (m_vAlignment != defaults->m_vAlignment)
-		textsubNode->AddProperty(_T("vertical-alignment"), m_vAlignment);
+	wxString hAlignment = m_alignment & wxALIGN_CENTER_HORIZONTAL ? wxT("center")
+			: m_alignment & wxALIGN_RIGHT ? wxT("right") : wxT("left");
+	if ((type == DVDAUTHOR_XML && hAlignment != wxT("left"))
+			|| (type == DVDSTYLER_XML && hAlignment != wxT("center")))
+		textsubNode->AddProperty(_T("horizontal-alignment"), hAlignment);
+	wxString vAlignment = m_alignment & wxALIGN_CENTER_VERTICAL ? wxT("center")
+				: m_alignment & wxALIGN_BOTTOM ? wxT("bottom") : wxT("top");
+	if (vAlignment != wxT("bottom"))
+		textsubNode->AddProperty(_T("vertical-alignment"), vAlignment);
 	if (m_leftMargin != defaults->m_leftMargin)
 		textsubNode->AddProperty(_T("left-margin"), wxString::Format(wxT("%d"), m_leftMargin));
 	if (m_rightMargin != defaults->m_rightMargin)
@@ -85,11 +102,26 @@ bool TextSub::PutXML(wxSvgXmlNode* node) {
 		return false;
 
 	node->GetPropVal(wxT("characterset"), &m_characterSet);
-	node->GetPropVal(wxT("font"), &m_font);
+	node->GetPropVal(wxT("fontFamily"), &m_fontFamily);
+	node->GetPropVal(wxT("fontStyle"), &m_fontStyle);
 	if (node->GetPropVal(wxT("fontsize"), &val) && val.ToDouble(&dval))
 		m_fontSize = dval;
-	node->GetPropVal(wxT("horizontal-alignment"), &m_hAlignment);
-	node->GetPropVal(wxT("vertical-alignment"), &m_vAlignment);
+	m_alignment = wxALIGN_CENTER_HORIZONTAL;
+	if (node->GetPropVal(wxT("horizontal-alignment"), &val)) {
+		if (val == wxT("left"))
+			m_alignment = wxALIGN_LEFT;
+		else if (val == wxT("right"))
+			m_alignment = wxALIGN_RIGHT;
+	}
+	if (node->GetPropVal(wxT("vertical-alignment"), &val)) {
+		if (val == wxT("center"))
+			m_alignment = (wxAlignment) (m_alignment | wxALIGN_CENTER_VERTICAL);
+		else if (val == wxT("top"))
+			m_alignment = (wxAlignment) (m_alignment | wxALIGN_TOP);
+		else
+			m_alignment = (wxAlignment) (m_alignment | wxALIGN_BOTTOM);
+	} else
+		m_alignment = (wxAlignment) (m_alignment | wxALIGN_BOTTOM);
 	if (node->GetPropVal(wxT("left-margin"), &val) && val.ToLong(&lval))
 		m_leftMargin = lval;
 	if (node->GetPropVal(wxT("right-margin"), &val) && val.ToLong(&lval))
@@ -216,7 +248,8 @@ bool Vob::SetFilename(wxString value) {
 	wxFfmpegMediaDecoder ffmpeg;
 	bool ok = m_filename.length() && ffmpeg.Load(m_filename);
 	m_duration = ok && ffmpeg.GetDuration() > 0 ? ffmpeg.GetDuration() : 0;
-	m_streams.RemoveAt(0, m_streams.GetCount() - m_audioFilenames.GetCount());
+	if (m_streams.GetCount() - m_audioFilenames.GetCount() > 0)
+		m_streams.RemoveAt(0, m_streams.GetCount() - m_audioFilenames.GetCount());
 	for (unsigned int stIdx = 0; stIdx < ffmpeg.GetStreamCount(); stIdx++) {
 		Stream* stream = new Stream(ffmpeg.GetStreamType(stIdx), ffmpeg.GetCodecName(stIdx));
 		if (stream->GetType() == stAUDIO) {
@@ -431,6 +464,7 @@ bool Vob::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi) {
 					val = dvd->GetPath() + fname.GetFullName();
 				SetFilename(val);
 			}
+			
 			if (child->GetPropVal(wxT("format"), &val) && val.length() > 0 && val.ToLong(&lval)) {
 				if ((int)m_streams.GetCount() <= stIdx || m_streams[stIdx]->GetType() != stVIDEO)
 					stIdx = 0;
@@ -581,6 +615,22 @@ Vob* Vob::CreateEmptyVob(VideoFormat videoFormat, AudioFormat audioFormat) {
 
 ////////////////////////////////// Pgc //////////////////////////////////////
 
+wxString Pgc::GetEntriesAsString() {
+	wxString result;
+	for (StringSet::const_iterator entry = m_entries.begin(); entry != m_entries.end(); entry++) {
+		if (result.length())
+			result += wxT(",");
+		result += *entry;
+	}
+	return result;
+}
+
+void Pgc::RemoveEntries(const StringSet& entries) {
+	for (StringSet::const_iterator entry = entries.begin(); entry != entries.end(); entry++) {
+		m_entries.erase(*entry);
+	}
+}
+
 Menu* Pgc::GetMenu() {
 	for (int i = 0; i < (int) GetVobs().GetCount(); i++)
 		if (GetVobs()[i]->GetMenu())
@@ -615,8 +665,8 @@ unsigned int Pgc::GetChapterCount() {
 
 wxSvgXmlNode* Pgc::GetXML(DVDFileType type, DVD* dvd, wxString nextTitle) {
 	wxSvgXmlNode* node = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, wxT("pgc"));
-	if (m_entry.length())
-		node->AddProperty(wxT("entry"), m_entry);
+	if (m_entries.size() > 0)
+		node->AddProperty(wxT("entry"), GetEntriesAsString());
 
 	if (m_palette.length())
 		node->AddProperty(wxT("palette"), m_palette);
@@ -648,7 +698,13 @@ bool Pgc::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi) {
 	WX_CLEAR_ARRAY(GetVobs());
 
 	wxString val;
-	node->GetPropVal(wxT("entry"), &m_entry);
+	m_entries.clear();
+	if (node->GetPropVal(wxT("entry"), &val)) {
+		wxArrayString entryArray = wxStringTokenize(val, wxT(","));
+		for (unsigned int entryIdx = 0; entryIdx < entryArray.Count(); entryIdx++)
+			m_entries.insert(entryArray[entryIdx]);
+	}
+
 	node->GetPropVal(wxT("palette"), &m_palette);
 
 	wxSvgXmlNode* child = node->GetChildren();
@@ -771,16 +827,25 @@ void PgcArray::UpdateAudioLangCodes() {
 			m_audioLangCodes.pop_back();
 }
 
+void PgcArray::UpdateSubtitleLangCodes() {
+	unsigned int subtitleCnt = GetSubtitleStreamsCount();
+	while (m_subtitleLangCodes.size() < subtitleCnt)
+		m_subtitleLangCodes.push_back(s_config.GetDefSubtitleLanguage());
+	while (m_subtitleLangCodes.size() > subtitleCnt)
+		m_subtitleLangCodes.pop_back();
+}
+
 ////////////////////////////////// Menus //////////////////////////////////////
 StringSet Menus::GetEntries() {
 	StringSet entries;
 	if (Count() > 0)
 		entries.insert(wxT("root"));
 	for (unsigned int pgci = 0; pgci < Count(); pgci++) {
-		wxArrayString entryArray = wxStringTokenize(Item(pgci)->GetEntry(), wxT(","));
-		for (unsigned int entryIdx = 0; entryIdx < entryArray.Count(); entryIdx++)
-			if (entryArray[entryIdx] != wxT("root"))
-				entries.insert(entryArray[entryIdx]);
+		const StringSet& pgcEntries = Item(pgci)->GetEntries();
+		for (StringSet::const_iterator entry = pgcEntries.begin(); entry != pgcEntries.end(); entry++) {
+			if (*entry != wxT("root"))
+				entries.insert(*entry);
+		}
 	}
 	return entries;
 }
@@ -835,6 +900,12 @@ wxSvgXmlNode* Titles::GetXML(DVDFileType type, DVD* dvd, int nextTitleset) {
 		audio->AddProperty(wxT("lang"), *it);
 		node->AddChild(audio);
 	}
+	UpdateSubtitleLangCodes();
+	for (wxArrayString::iterator it = GetSubtitleLangCodes().begin(); it != GetSubtitleLangCodes().end(); it++) {
+		wxSvgXmlNode* audio = new wxSvgXmlNode(wxSVGXML_ELEMENT_NODE, wxT("subpicture"));
+		audio->AddProperty(wxT("lang"), *it);
+		node->AddChild(audio);
+	}
 	if (GetVideo().GetXML(type))
 		node->AddChild(GetVideo().GetXML(type));
 	for (int i = 0; i < (int) GetCount(); i++) {
@@ -851,11 +922,13 @@ bool Titles::PutXML(wxSvgXmlNode* node, DVD* dvd, int tsi) {
 		return false;
 	wxSvgXmlNode* child = node->GetChildren();
 	while (child) {
-		if (child->GetName() == wxT("audio") && child->HasAttribute(wxT("lang")))
+		if (child->GetName() == wxT("audio") && child->HasAttribute(wxT("lang"))) {
 			GetAudioLangCodes().Add(child->GetAttribute(wxT("lang")));
-		else if (child->GetName() == wxT("video"))
+		} else if (child->GetName() == wxT("subpicture") && child->HasAttribute(wxT("lang"))) {
+			GetSubtitleLangCodes().Add(child->GetAttribute(wxT("lang")));
+		} else if (child->GetName() == wxT("video")) {
 			GetVideo().PutXML(child);
-		else if (child->GetName() == wxT("pgc")) {
+		} else if (child->GetName() == wxT("pgc")) {
 			Pgc* pgc = new Pgc;
 			if (pgc->PutXML(child, dvd, tsi))
 				Add(pgc);
@@ -1124,7 +1197,7 @@ Menu* DVD::GetMenu(int tsi, int pgci) {
 }
 
 /** Returns true if all actions are valid */
-bool DVD::CheckActions() {
+bool DVD::CheckActions(bool skipInvalidTarget) {
 	bool valid = true;
 	for (int tsi = -1; tsi < (int) GetTitlesets().Count(); tsi++) {
 		PgcArray& pgcs = GetPgcArray(tsi, true);
@@ -1133,26 +1206,58 @@ bool DVD::CheckActions() {
 			if (menu) {
 				for (unsigned int obji = 0; obji < menu->GetObjectsCount(); obji++) {
 					MenuObject* obj = menu->GetObject(obji);
-					if (obj->IsButton()
-							&& !obj->GetAction().IsValid(this, tsi, pgci, true, obj->GetId(true), true))
+					if (obj->IsButton() && !obj->GetAction().IsValid(
+							this, tsi, pgci, true, obj->GetId(true), true, true, skipInvalidTarget))
+						valid = false;
+				}
+			}
+			// check commands
+			if (pgcs[pgci]->GetPreCommands().length()) {
+				DVDAction action(false, BUTTON_ACTION);
+				action.SetCustom(pgcs[pgci]->GetPreCommands());
+				if (!action.IsValid(this, tsi, pgci, true, wxT(""), true))
+					valid = false;
+			}
+			if (pgcs[pgci]->GetPostCommands().length()) {
+				DVDAction action(false, BUTTON_ACTION);
+				action.SetCustom(pgcs[pgci]->GetPostCommands());
+				if (!action.IsValid(this, tsi, pgci, true, wxT(""), true))
+					valid = false;
+			}
+		}
+		if (tsi >= 0) {
+			PgcArray& pgcs = GetPgcArray(tsi, false);
+			for (unsigned int pgci = 0; pgci < pgcs.GetCount(); pgci++) {
+				// check commands
+				if (pgcs[pgci]->GetPreCommands().length()) {
+					DVDAction action(false, BUTTON_ACTION);
+					action.SetCustom(pgcs[pgci]->GetPreCommands());
+					if (!action.IsValid(this, tsi, pgci, false, wxT(""), true))
+						valid = false;
+				}
+				if (pgcs[pgci]->GetPostCommands().length()) {
+					DVDAction action(false, BUTTON_ACTION);
+					action.SetCustom(pgcs[pgci]->GetPostCommands());
+					if (!action.IsValid(this, tsi, pgci, false, wxT(""), true))
 						valid = false;
 				}
 			}
 		}
 	}
-	if (!valid)
+	if (!valid) {
 		wxLogError(_("Some actions are invalid. Please click 'Details' for more information."));
+	}
 	return valid;
 }
 
-/** Updates image in buttons with action jump to given title */
-void DVD::UpdateButtonImageFor(int actionTsi, int actionPgci, wxString uri) {
+/** Updates image in buttons with given jump action */
+void DVD::UpdateButtonImageFor(int actionTsi, int actionPgci) {
 	for (int tsi = -1; tsi < (int) GetTitlesets().GetCount(); tsi++) {
 		PgcArray& pgcs = GetPgcArray(tsi, true);
 		for (unsigned int pgci = 0; pgci < pgcs.GetCount(); pgci++) {
 			Menu* menu = pgcs[pgci]->GetMenu();
 			if (menu)
-				menu->UpdateButtonImageFor(actionTsi != tsi ? actionTsi : -2, actionPgci, uri);
+				menu->UpdateButtonImageFor(actionTsi != tsi ? actionTsi : -2, actionPgci, this);
 		}
 	}
 }
@@ -1431,7 +1536,7 @@ bool DVD::IsRegisterUsed(int g) {
 	return false;
 }
 
-wxArrayString DVD::GetVideoFormatLabels(bool copy, bool none) {
+wxArrayString DVD::GetVideoFormatLabels(bool copy, bool none, bool menu) {
 	wxArrayString formats;
 	if (none)
 		formats.Add(_("None"));
@@ -1439,6 +1544,14 @@ wxArrayString DVD::GetVideoFormatLabels(bool copy, bool none) {
 		formats.Add(_("Copy"));
 	formats.Add(wxT("PAL 720x576"));
 	formats.Add(wxT("NTSC 720x480"));
+	if (!menu) {
+		formats.Add(wxT("PAL 704x576"));
+		formats.Add(wxT("NTSC 704x480"));
+		formats.Add(wxT("PAL 352x576"));
+		formats.Add(wxT("NTSC 352x480"));
+		formats.Add(wxT("PAL 352x288"));
+		formats.Add(wxT("NTSC 352x240"));
+	}
 	return formats;
 }
 
@@ -1448,8 +1561,8 @@ wxArrayString DVD::GetAudioFormatLabels(bool copy, bool none) {
 		formats.Add(_("None"));
 	if (copy)
 		formats.Add(_("Copy"));
-	formats.Add(wxT("MP2 48 kHz"));
-	formats.Add(wxT("AC3 48 kHz"));
+	formats.Add(_("MP2 48 kHz"));
+	formats.Add(_("AC3 48 kHz"));
 	return formats;
 }
 
@@ -1464,9 +1577,9 @@ wxArrayString DVD::GetAspectRatioLabels(bool autom) {
 
 wxArrayString DVD::GetCapacityLabels() {
 	wxArrayString labels;
-	labels.Add(wxT("4.7 GB"));
-	labels.Add(wxT("8.5 GB"));
-	labels.Add(wxT("Unlimited"));
+	labels.Add(_("4.7 GB"));
+	labels.Add(_("8.5 GB"));
+	labels.Add(_("Unlimited"));
 	return labels;
 }
 
@@ -1531,8 +1644,238 @@ const wxString audioLangCodesArray[] = { wxT("AA"), wxT("AB"), wxT("AF"), wxT("A
 		wxT("TE"), wxT("TG"), wxT("TH"), wxT("TI"), wxT("TK"), wxT("TL"), wxT("TN"), wxT("TO"), wxT("TR"),
 		wxT("TS"), wxT("TT"), wxT("TW"), wxT("UK"), wxT("UR"), wxT("UZ"), wxT("VI"), wxT("VO"), wxT("WO"),
 		wxT("XH"), wxT("YO"), wxT("ZH"), wxT("ZU") };
-static wxArrayString audioLanguageCodes(136, audioLangCodesArray);
+static wxArrayString s_audioLanguageCodes(136, audioLangCodesArray);
 
 wxArrayString DVD::GetAudioLanguageCodes() {
-	return audioLanguageCodes;
+	return s_audioLanguageCodes;
+}
+
+static map<wxString, wxString> s_languageMap;
+
+map<wxString, wxString>& DVD::GetLanguageMap() {
+	if (s_languageMap.size() == 0) {
+		s_languageMap[wxT("Abkhazian")] = wxT("AB");
+		s_languageMap[wxT("Afar")] = wxT("AA");
+		s_languageMap[wxT("Afrikaans")] = wxT("AF");
+		s_languageMap[wxT("Akan")] = wxT("AK");
+		s_languageMap[wxT("Albanian")] = wxT("SQ");
+		s_languageMap[wxT("Amharic")] = wxT("AM");
+		s_languageMap[wxT("Arabic")] = wxT("AR");
+		s_languageMap[wxT("Aragonese")] = wxT("AN");
+		s_languageMap[wxT("Assamese")] = wxT("AS");
+		s_languageMap[wxT("Armenian")] = wxT("HY");
+		s_languageMap[wxT("Avaric")] = wxT("AV");
+		s_languageMap[wxT("Avestan")] = wxT("AE");
+		s_languageMap[wxT("Aymara")] = wxT("AY");
+		s_languageMap[wxT("Azerbaijani")] = wxT("AZ");
+		s_languageMap[wxT("Bashkir")] = wxT("BA");
+		s_languageMap[wxT("Bambara")] = wxT("BM");
+		s_languageMap[wxT("Basque")] = wxT("EU");
+		s_languageMap[wxT("Belarusian")] = wxT("BE");
+		s_languageMap[wxT("Bengali")] = wxT("BN");
+		s_languageMap[wxT("Bihari")] = wxT("BH");
+		s_languageMap[wxT("Bislama")] = wxT("BI");
+		s_languageMap[wxT("Bosnian")] = wxT("BS");
+		s_languageMap[wxT("Breton")] = wxT("BR");
+		s_languageMap[wxT("Bulgarian")] = wxT("BG");
+		s_languageMap[wxT("Burmese")] = wxT("MY");
+		s_languageMap[wxT("Catalan; Valencian")] = wxT("CA");
+		s_languageMap[wxT("Chamorro")] = wxT("CH");
+		s_languageMap[wxT("Chechen")] = wxT("CE");
+		s_languageMap[wxT("Chichewa; Chewa; Nyanja")] = wxT("NY");
+		s_languageMap[wxT("Chinese")] = wxT("ZH");
+		s_languageMap[wxT("Chuvash")] = wxT("CV");
+		s_languageMap[wxT("Cornish")] = wxT("KW");
+		s_languageMap[wxT("Corsican")] = wxT("CO");
+		s_languageMap[wxT("Cree")] = wxT("CR");
+		s_languageMap[wxT("Croatian")] = wxT("HR");
+		s_languageMap[wxT("Czech")] = wxT("CS");
+		s_languageMap[wxT("Danish")] = wxT("DA");
+		s_languageMap[wxT("Divehi; Dhivehi; Maldivian;")] = wxT("DV");
+		s_languageMap[wxT("Dzongkha")] = wxT("DZ");
+		s_languageMap[wxT("English")] = wxT("EN");
+		s_languageMap[wxT("Esperanto")] = wxT("EO");
+		s_languageMap[wxT("Estonian")] = wxT("ET");
+		s_languageMap[wxT("Ewe")] = wxT("EE");
+		s_languageMap[wxT("Faroese")] = wxT("FO");
+		s_languageMap[wxT("Fijian")] = wxT("FJ");
+		s_languageMap[wxT("Finnish")] = wxT("FI");
+		s_languageMap[wxT("French")] = wxT("FR");
+		s_languageMap[wxT("Fula; Fulah; Pulaar; Pular")] = wxT("FF");
+		s_languageMap[wxT("Galician")] = wxT("GL");
+		s_languageMap[wxT("German")] = wxT("DE");
+		s_languageMap[wxT("Greek, Modern")] = wxT("EL");
+		s_languageMap[wxT("Guarani")] = wxT("GN");
+		s_languageMap[wxT("Gujarati")] = wxT("GU");
+		s_languageMap[wxT("Haitian; Haitian Creole")] = wxT("HT");
+		s_languageMap[wxT("Hausa")] = wxT("HA");
+		s_languageMap[wxT("Hebrew, Modern")] = wxT("HE");
+		s_languageMap[wxT("Herero")] = wxT("HZ");
+		s_languageMap[wxT("Hindi")] = wxT("HI");
+		s_languageMap[wxT("Hiri Motu")] = wxT("HO");
+		s_languageMap[wxT("Hungarian")] = wxT("HU");
+		s_languageMap[wxT("Interlingua")] = wxT("IA");
+		s_languageMap[wxT("Indonesian")] = wxT("ID");
+		s_languageMap[wxT("Interlingue, Occidental")] = wxT("IE");
+		s_languageMap[wxT("Irish")] = wxT("GA");
+		s_languageMap[wxT("Igbo")] = wxT("IG");
+		s_languageMap[wxT("Sichuan Yi, Nuosu")] = wxT("II");
+		s_languageMap[wxT("Inupiaq")] = wxT("IK");
+		s_languageMap[wxT("Ido")] = wxT("IO");
+		s_languageMap[wxT("Icelandic")] = wxT("IS");
+		s_languageMap[wxT("Italian")] = wxT("IT");
+		s_languageMap[wxT("Inuktitut")] = wxT("IU");
+		s_languageMap[wxT("Japanese")] = wxT("JA");
+		s_languageMap[wxT("Javanese")] = wxT("JV");
+		s_languageMap[wxT("Georgian")] = wxT("KA");
+		s_languageMap[wxT("Kongo")] = wxT("KG");
+		s_languageMap[wxT("Kikuyu, Gikuyu")] = wxT("KI");
+		s_languageMap[wxT("Kwanyama, Kuanyama")] = wxT("KJ");
+		s_languageMap[wxT("Kazakh")] = wxT("KK");
+		s_languageMap[wxT("Kalaallisut, Greenlandic")] = wxT("KL");
+		s_languageMap[wxT("Central Khmer")] = wxT("KM");
+		s_languageMap[wxT("Kannada")] = wxT("KN");
+		s_languageMap[wxT("Korean")] = wxT("KO");
+		s_languageMap[wxT("Kanuri")] = wxT("KR");
+		s_languageMap[wxT("Kashmiri")] = wxT("KS");
+		s_languageMap[wxT("Kurdish")] = wxT("KU");
+		s_languageMap[wxT("Komi")] = wxT("KV");
+		s_languageMap[wxT("Kirghiz, Kyrgyz")] = wxT("KY");
+		s_languageMap[wxT("Latin")] = wxT("LA");
+		s_languageMap[wxT("Luxembourgish")] = wxT("LB");
+		s_languageMap[wxT("Luganda")] = wxT("LG");
+		s_languageMap[wxT("Limburgish")] = wxT("LI");
+		s_languageMap[wxT("Lingala")] = wxT("LN");
+		s_languageMap[wxT("Lao")] = wxT("LO");
+		s_languageMap[wxT("Lithuanian")] = wxT("LT");
+		s_languageMap[wxT("Luba-Katanga")] = wxT("LU");
+		s_languageMap[wxT("Latvian")] = wxT("LV");
+		s_languageMap[wxT("Malagasy")] = wxT("MG");
+		s_languageMap[wxT("Marshallese")] = wxT("MH");
+		s_languageMap[wxT("Manx")] = wxT("GV");
+		s_languageMap[wxT("Maori")] = wxT("MI");
+		s_languageMap[wxT("Macedonian")] = wxT("MK");
+		s_languageMap[wxT("Malayalam")] = wxT("ML");
+		s_languageMap[wxT("Mongolian")] = wxT("MN");
+		s_languageMap[wxT("Marathi")] = wxT("MR");
+		s_languageMap[wxT("Malay")] = wxT("MS");
+		s_languageMap[wxT("Maltese")] = wxT("MT");
+		s_languageMap[wxT("Nauru")] = wxT("NA");
+		s_languageMap[wxT("Norwegian Bokmal")] = wxT("NB");
+		s_languageMap[wxT("North Ndebele")] = wxT("ND");
+		s_languageMap[wxT("Nepali")] = wxT("NE");
+		s_languageMap[wxT("Ndonga")] = wxT("NG");
+		s_languageMap[wxT("Dutch, Flemish")] = wxT("NL");
+		s_languageMap[wxT("Norwegian Nynorsk")] = wxT("NN");
+		s_languageMap[wxT("Norwegian")] = wxT("NO");
+		s_languageMap[wxT("South Ndebele")] = wxT("NR");
+		s_languageMap[wxT("Navajo, Navaho")] = wxT("NV");
+		s_languageMap[wxT("Occitan (after 1500)")] = wxT("OC");
+		s_languageMap[wxT("Ojibwa")] = wxT("OJ");
+		s_languageMap[wxT("Church Slavic")] = wxT("CU");
+		s_languageMap[wxT("Oromo")] = wxT("OM");
+		s_languageMap[wxT("Oriya")] = wxT("OR");
+		s_languageMap[wxT("Ossetian, Ossetic")] = wxT("OS");
+		s_languageMap[wxT("Panjabi, Punjabi")] = wxT("PA");
+		s_languageMap[wxT("Pali")] = wxT("PI");
+		s_languageMap[wxT("Persian")] = wxT("FA");
+		s_languageMap[wxT("Polish")] = wxT("PL");
+		s_languageMap[wxT("Pashto, Pushto")] = wxT("PS");
+		s_languageMap[wxT("Portuguese")] = wxT("PT");
+		s_languageMap[wxT("Quechua")] = wxT("QU");
+		s_languageMap[wxT("Romansh")] = wxT("RM");
+		s_languageMap[wxT("Kirundi")] = wxT("RN");
+		s_languageMap[wxT("Romanian, Moldavian")] = wxT("RO");
+		s_languageMap[wxT("Russian")] = wxT("RU");
+		s_languageMap[wxT("Kinyarwanda")] = wxT("RW");
+		s_languageMap[wxT("Sanskrit")] = wxT("SA");
+		s_languageMap[wxT("Sardinian")] = wxT("SC");
+		s_languageMap[wxT("Sindhi")] = wxT("SD");
+		s_languageMap[wxT("Northern Sami")] = wxT("SE");
+		s_languageMap[wxT("Samoan")] = wxT("SM");
+		s_languageMap[wxT("Sango")] = wxT("SG");
+		s_languageMap[wxT("Serbian")] = wxT("SR");
+		s_languageMap[wxT("Scottish Gaelic; Gaelic")] = wxT("GD");
+		s_languageMap[wxT("Shona")] = wxT("SN");
+		s_languageMap[wxT("Sinhala, Sinhalese")] = wxT("SI");
+		s_languageMap[wxT("Slovak")] = wxT("SK");
+		s_languageMap[wxT("Slovene")] = wxT("SL");
+		s_languageMap[wxT("Somali")] = wxT("SO");
+		s_languageMap[wxT("Southern Sotho")] = wxT("ST");
+		s_languageMap[wxT("Spanish; Castilian")] = wxT("ES");
+		s_languageMap[wxT("Sundanese")] = wxT("SU");
+		s_languageMap[wxT("Swahili")] = wxT("SW");
+		s_languageMap[wxT("Swati")] = wxT("SS");
+		s_languageMap[wxT("Swedish")] = wxT("SV");
+		s_languageMap[wxT("Tamil")] = wxT("TA");
+		s_languageMap[wxT("Telugu")] = wxT("TE");
+		s_languageMap[wxT("Tajik")] = wxT("TG");
+		s_languageMap[wxT("Thai")] = wxT("TH");
+		s_languageMap[wxT("Tigrinya")] = wxT("TI");
+		s_languageMap[wxT("Tibetan")] = wxT("BO");
+		s_languageMap[wxT("Turkmen")] = wxT("TK");
+		s_languageMap[wxT("Tagalog")] = wxT("TL");
+		s_languageMap[wxT("Tswana")] = wxT("TN");
+		s_languageMap[wxT("Tonga (Tonga Islands)")] = wxT("TO");
+		s_languageMap[wxT("Turkish")] = wxT("TR");
+		s_languageMap[wxT("Tsonga")] = wxT("TS");
+		s_languageMap[wxT("Tatar")] = wxT("TT");
+		s_languageMap[wxT("Twi")] = wxT("TW");
+		s_languageMap[wxT("Tahitian")] = wxT("TY");
+		s_languageMap[wxT("Uighur, Uyghur")] = wxT("UG");
+		s_languageMap[wxT("Ukrainian")] = wxT("UK");
+		s_languageMap[wxT("Urdu")] = wxT("UR");
+		s_languageMap[wxT("Uzbek")] = wxT("UZ");
+		s_languageMap[wxT("Venda")] = wxT("VE");
+		s_languageMap[wxT("Vietnamese")] = wxT("VI");
+		s_languageMap[wxT("Volapuk")] = wxT("VO");
+		s_languageMap[wxT("Walloon")] = wxT("WA");
+		s_languageMap[wxT("Welsh")] = wxT("CY");
+		s_languageMap[wxT("Wolof")] = wxT("WO");
+		s_languageMap[wxT("Western Frisian")] = wxT("FY");
+		s_languageMap[wxT("Xhosa")] = wxT("XH");
+		s_languageMap[wxT("Yiddish")] = wxT("YI");
+		s_languageMap[wxT("Yoruba")] = wxT("YO");
+		s_languageMap[wxT("Zhuang, Chuang")] = wxT("ZA");
+		s_languageMap[wxT("Zulu")] = wxT("ZU");
+	}
+	return s_languageMap;
+}
+
+static wxArrayString s_languageNames;
+
+wxArrayString& DVD::GetLanguageNames() {
+	if (s_languageNames.size() == 0) {
+		map<wxString, wxString>& langMap = DVD::GetLanguageMap();
+		for (map<wxString, wxString>::iterator it = langMap.begin(); it != langMap.end(); it++) {
+			s_languageNames.Add(it->first);
+		}
+	}
+	return s_languageNames;
+}
+
+const wxString charsetsArray[] = {
+	wxT("ASCII"), wxT("BIG5"), wxT("BIG5-HKSCS"), wxT("BIG5-HKSCS:2001"), wxT("BIG5-HKSCS:1999"),
+	wxT("CP850"), wxT("CP862"), wxT("CP866"), wxT("CP874"), wxT("CP932"), wxT("CP936"), wxT("CP949"), wxT("CP950"),
+	wxT("CP1131"), wxT("CP1133"), wxT("CP1250"), wxT("CP1251"), wxT("CP1252"),wxT("CP1133"),
+	wxT("CP1253"), wxT("CP1254"), wxT("CP1255"), wxT("CP1256"), wxT("CP1257"), wxT("CP1258"),
+	wxT("EUC-CN"), wxT("EUC-JP"), wxT("EUC-KR"), wxT("EUC-TW"),
+	wxT("GB18030"), wxT("GBK"), wxT("Georgian-Academy"), wxT("Georgian-PS"), wxT("HZ"),
+	wxT("ISO-2022-CN"), wxT("ISO-2022-CN-EXT"), wxT("ISO-2022-JP"), wxT("ISO-2022-JP-2"), wxT("ISO-2022-JP-1"),
+	wxT("ISO-2022-KR"), wxT("ISO-8859-1"), wxT("ISO-8859-2"), wxT("ISO-8859-3"), wxT("ISO-8859-4"), wxT("ISO-8859-5"),
+	wxT("ISO-8859-6"), wxT("ISO-8859-7"), wxT("ISO-8859-8"), wxT("ISO-8859-9"), wxT("ISO-8859-10"), wxT("ISO-8859-11"),
+	wxT("ISO-8859-13"), wxT("ISO-8859-14"), wxT("ISO-8859-15"), wxT("ISO-8859-16"),
+	wxT("JOHAB"), wxT("KOI8-R"), wxT("KOI8-RU"), wxT("KOI8-T"), wxT("KOI8-U"),
+	wxT("Macintosh"), wxT("MacArabic"), wxT("MacCentralEurope"), wxT("MacCroatian"), wxT("MacCyrillic"),
+	wxT("MacGreek"), wxT("MacHebrew"), wxT("MacIceland"), wxT("MacRoman"), wxT("MacRomania"), wxT("MacThai"),
+	wxT("MacTurkish"), wxT("MacUkraine"), wxT("MuleLao-1"),
+	wxT("PT154"), wxT("RK1048"), wxT("SHIFT_JIS"), wxT("TCVN"), wxT("TIS-620"),
+	wxT("UCS-2"), wxT("UCS-2BE"), wxT("UCS-2LE"), wxT("UCS-4"), wxT("UCS-4BE"), wxT("UCS-4LE"),
+	wxT("UTF-7"), wxT("UTF-8"), wxT("UTF-16"), wxT("UTF-16BE"), wxT("UTF-16LE"),
+	wxT("UTF-32"), wxT("UTF-32BE"), wxT("UTF-32LE"), wxT("VISCII")
+};
+static wxArrayString s_charsets(80, charsetsArray);
+
+wxArrayString& DVD::GetCharsets() {
+	return s_charsets;
 }
