@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Structure (Titles/Menus)
 // Author:      Alex Thuering
 // Created:	29.01.2003
-// RCS-ID:      $Id: DVD.h,v 1.48 2010/01/24 18:56:06 ntalex Exp $
+// RCS-ID:      $Id: DVD.h,v 1.52 2010/05/03 06:03:20 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -11,12 +11,15 @@
 #ifndef DVDAUTHOR_H
 #define DVDAUTHOR_H
 
+#include "Slideshow.h"
 #include <wx/wx.h>
 #include <wx/image.h>
 #include <wx/dynarray.h>
 #include <wx/hashset.h>
 #include <wxSVG/mediadec_ffmpeg.h>
-#include "Slideshow.h"
+#include <map>
+
+using namespace std;
 
 WX_DECLARE_HASH_SET(wxString, wxStringHash, wxStringEqual, StringSet);
 
@@ -28,63 +31,65 @@ class Cache;
 
 class TextSub {
 public:
-    TextSub(wxString filename = wxT(""));
+	TextSub(wxString filename = wxT(""));
+
+	wxString GetFilename() { return m_filename; }
+	void SetFilename(wxString value) { m_filename = value; }
 	
-    wxString GetFilename() { return m_filename; }
-    void SetFilename(wxString value) { m_filename = value; }
+	wxString GetCharacterSet() { return m_characterSet; }
+	void SetCharacterSet(wxString value) { m_characterSet= value; }
 	
-    wxString GetCharacterSet() { return m_characterSet; }
-    void SetCharacterSet(wxString value) { m_characterSet= value; }
+	wxString GetFontFile();
 	
-    wxString GetFont() { return m_font; }
-    void Set(wxString value) { m_font = value; }
+	wxString GetFontFamily() { return m_fontFamily; }
+	void SetFontFamily(wxString value) { m_fontFamily = value; }
 	
-    double GetFontSize() { return m_fontSize; }
-    void SetFontSize(double value) { m_fontSize = value; }
+	wxString GetFontStyle() { return m_fontStyle; }
+	void SetFontStyle(wxString value) { m_fontStyle = value; }
+
+	double GetFontSize() { return m_fontSize; }
+	void SetFontSize(double value) { m_fontSize = value; }
 	
-    wxString GetHAlignment() { return m_hAlignment; }
-    void SetHAlignment(wxString value) { m_hAlignment = value; }
+	wxAlignment GetAlignment() { return m_alignment; }
+	void SetAlignment(wxAlignment value) { m_alignment = value; }
 	
-    wxString GetVAlignment() { return m_vAlignment; }
-    void SetVAlignment(wxString value) { m_vAlignment = value; }
+	int GetLeftMargin() { return m_leftMargin; }
+	void SetLeftMargin(int value) { m_leftMargin = value; }
 	
-    int GetLeftMargin() { return m_leftMargin; }
-    void SetLeftMargin(int value) { m_leftMargin = value; }
+	int GetRightMargin() { return m_rightMargin; }
+	void SetRightMargin(int value) { m_rightMargin = value; }
 	
-    int GetRightMargin() { return m_rightMargin; }
-    void SetRightMargin(int value) { m_rightMargin = value; }
+	int GetTopMargin() { return m_topMargin; }
+	void SetTopMargin(int value) { m_topMargin = value; }
 	
-    int GetTopMargin() { return m_topMargin; }
-    void SetTopMargin(int value) { m_topMargin = value; }
+	int GetBottomMargin() { return m_bottomMargin; }
+	void SetBottomMargin(int value) { m_bottomMargin = value; }
 	
-    int GetmBottomMargin() { return m_bottomMargin; }
-    void SetBottomMargin(int value) { m_bottomMargin = value; }
+	double GetSubtitleFps() { return m_subtitleFps; }
+	void SetSubtitleFps(double value) { m_subtitleFps = value; }
 	
-    double GetSubtitleFps() { return m_subtitleFps; }
-    void SetSubtitleFps(double value) { m_subtitleFps = value; }
+	double GetMovieFps() { return m_movieFps; }
+	void SetMovieFps(double value) { m_movieFps = value; }
 	
-    double GetMovieFps() { return m_movieFps; }
-    void SetMovieFps(double value) { m_movieFps = value; }
+	int GetMovieWidth() { return m_movieWidth; }
+	void SetMovieWidth(int value) { m_movieWidth = value; }
 	
-    int GetMovieWidth() { return m_movieWidth; }
-    void SetMovieWidth(int value) { m_movieWidth = value; }
+	int GetMovieHeight() { return m_movieHeight; }
+	void SetMovieHeight(int value) { m_movieHeight = value; }
 	
-    int GetMovieHeight() { return m_movieHeight; }
-    void SetMovieHeight(int value) { m_movieHeight = value; }
-	
-    wxSvgXmlNode* GetXML(DVDFileType type);
+	wxSvgXmlNode* GetXML(DVDFileType type);
 	bool PutXML(wxSvgXmlNode* node);
 	
-    /** saves a configuration for spumux */
+	/** saves a configuration for spumux */
 	bool SaveSpumux(wxString filename);
 	
 private:
     wxString m_filename;
     wxString m_characterSet;
-    wxString m_font;
+    wxString m_fontFamily;
+    wxString m_fontStyle;
     double m_fontSize;
-    wxString m_hAlignment;
-    wxString m_vAlignment;
+    wxAlignment m_alignment;
     int m_leftMargin;
     int m_rightMargin;
     int m_topMargin;
@@ -256,8 +261,10 @@ public:
 	Pgc() { }
 	~Pgc() { WX_CLEAR_ARRAY(m_vobs) }
 	
-	void SetEntry(wxString value) { m_entry = value; }
-	wxString GetEntry() { return m_entry; }
+	wxString GetEntriesAsString();
+	const StringSet& GetEntries() { return m_entries; }
+	void SetEntries(const StringSet& entries) { m_entries = entries; }
+	void RemoveEntries(const StringSet& entries);
 	
 	void SetPreCommands(wxString value) { m_pre = value; }
 	wxString GetPreCommands() { return m_pre; }
@@ -278,7 +285,8 @@ public:
 	
 private:
 	VobArray m_vobs;
-	wxString m_entry, m_pre, m_post, m_palette;
+	StringSet m_entries;
+	wxString m_pre, m_post, m_palette;
 };
 
 WX_DEFINE_ARRAY(Pgc*, PgcArrayBase);
@@ -317,6 +325,7 @@ private:
 class PgcArray: public PgcArrayBase {
 public:
 	wxArrayString& GetAudioLangCodes() { return m_audioLangCodes; }
+	wxArrayString& GetSubtitleLangCodes() { return m_subtitleLangCodes; }
 	Video& GetVideo() { return m_video; }
 	
 	/** Returns count of audio streams */
@@ -326,8 +335,10 @@ public:
 	
 protected:
 	wxArrayString m_audioLangCodes;
+	wxArrayString m_subtitleLangCodes;
 	Video m_video;
 	void UpdateAudioLangCodes();
+	void UpdateSubtitleLangCodes();
 };
 
 class Menus: public PgcArray {
@@ -460,9 +471,9 @@ public:
 	/** returns menu from titleset tsi und pgc pgci */
 	Menu* GetMenu(int tsi, int pgci);
 	/** Returns true if all actions are valid */
-	bool CheckActions();
-	/** Updates image in buttons with action jump to given title */
-	void UpdateButtonImageFor(int actionTsi, int actionPgci, wxString uri);
+	bool CheckActions(bool skipInvalidTarget);
+	/** Updates image in buttons with given jump action */
+	void UpdateButtonImageFor(int actionTsi, int actionPgci);
 	/** Fix coordinates of buttons if they are out of range */
 	void FixButtonCoordinates();
 	
@@ -518,7 +529,7 @@ public:
     /** Saves a configuration for dvdauthor */
 	bool SaveDVDAuthor(wxString fname);
 	
-	static wxArrayString GetVideoFormatLabels(bool copy = false, bool none = false);
+	static wxArrayString GetVideoFormatLabels(bool copy = false, bool none = false, bool menu = false);
 	static wxArrayString GetAudioFormatLabels(bool copy = false, bool none = false);
 	static wxArrayString GetAspectRatioLabels(bool autom = false);
 	static wxArrayString GetCapacityLabels();
@@ -531,6 +542,12 @@ public:
 	static wxString GetAudioFormatName(AudioFormat format);
 	/** Returns list of available language codes for audio tracks (ISO 639) */
 	static wxArrayString GetAudioLanguageCodes();
+	/** Returns map of languages to language codes (ISO 639) */
+	static map<wxString, wxString>& GetLanguageMap();
+	/** Returns list of languages (ISO 639) */
+	static wxArrayString& GetLanguageNames();
+	/** Returns list of encodings supported by libiconv */
+	static wxArrayString& GetCharsets();
 	
 private:
 	/** project file name */
