@@ -3,7 +3,7 @@
 // Purpose:     DVD properties dialog
 // Author:      Alex Thuering
 // Created:     7.03.2005
-// RCS-ID:      $Id: DVDPropDlg.cpp,v 1.27 2010/01/10 11:49:42 ntalex Exp $
+// RCS-ID:      $Id: DVDPropDlg.cpp,v 1.28 2010/05/03 06:06:37 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -51,7 +51,7 @@ void DVDPropDlg::CreatePropPanel(wxSizer* sizer) {
 	wxSizer* grp = BeginGroup(fSizer, _("Video Format"));
 	if (grp)
 		grp->Add(4, 4);
-	wxArrayString formats = DVD::GetVideoFormatLabels();
+	wxArrayString formats = DVD::GetVideoFormatLabels(false, false, true);
 	AddRadioGroupProp(grp, formats, m_dvd->GetVideoFormat() - 2);
 	if (grp)
 		grp->Add(4, 4);
