@@ -3,7 +3,7 @@
 // Purpose:     Main window
 // Author:      Alex Thuering
 // Created:     10.10.2003
-// RCS-ID:      $Id: MainWin.cpp,v 1.135 2010/02/22 22:47:18 ntalex Exp $
+// RCS-ID:      $Id: MainWin.cpp,v 1.137 2010/04/28 07:33:34 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -219,13 +219,11 @@ MainWin::MainWin(): wxFrame(NULL, -1, _T(""), wxDefaultPosition, wxDefaultSize,
 	wxCommandEvent evt;
 	OnBackgroundsBt(evt);
 	VideoFormat vf = (VideoFormat) s_config.GetDefVideoFormat();
-	if (vf <= vfCOPY) vf = vfPAL;
 	AudioFormat af = (AudioFormat) s_config.GetDefAudioFormat();
-	if (af <= afCOPY) af = afMP2;
 	AspectRatio ar = (AspectRatio) s_config.GetDefAspectRatio();
-	if (ar <= arAUTO) ar = ar4_3;
-	NewDVD(wxT(""), wxT(""), s_config.GetDefDiscLabel(), (DiscCapacity) s_config.GetDefDiscCapacity(),
-			s_config.GetVideoBitrate(), vf, af, ar);
+	DiscCapacity dc = (DiscCapacity) s_config.GetDefDiscCapacity();
+	NewDVD(wxT(""), wxT(""), s_config.GetDefDiscLabel(), dc, s_config.GetVideoBitrate(),
+			vf <= vfCOPY ? vfPAL : vf, af <= afCOPY ? afMP2 : af, ar <= arAUTO ? ar4_3 : ar);
 
 	// Restore frame size/position
 	if (s_config.IsMainWinMaximized()) {
@@ -781,7 +779,7 @@ please drag a video file into the bottom section of the window."), emptyTsi+1),
 		return;
 	}
 	// check if all actions are valid
-	if (!m_dvd->HasTemplate() && !m_dvd->CheckActions())
+	if (!m_dvd->CheckActions(m_dvd->HasTemplate()))
 		return;
 	// fix coordinates of buttons if they are out of range
 	m_dvd->FixButtonCoordinates();
