@@ -3,7 +3,7 @@
 // Purpose:     The class to store a DVD Menu
 // Author:      Alex Thuering
 // Created:	04.11.2003
-// RCS-ID:      $Id: Menu.cpp,v 1.82 2010/02/22 22:47:18 ntalex Exp $
+// RCS-ID:      $Id: Menu.cpp,v 1.83 2010/05/03 06:03:20 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -548,16 +548,21 @@ wxString Menu::AddObject(wxString fileName, wxString param, int x, int y) {
 	return obj->GetId();
 }
 
-/** Updates image in buttons with action jump to given title */
-void Menu::UpdateButtonImageFor(int actionTsi, int actionPgci, wxString uri) {
+/** Updates image in buttons with given jump action */
+void Menu::UpdateButtonImageFor(int actionTsi, int actionPgci, DVD* dvd) {
 	for (unsigned int obji = 0; obji < m_objects.GetCount(); obji++) {
 		MenuObject* obj = m_objects[obji];
 		if (obj->IsButton() && !obj->GetAction().IsCustom()
 				&& obj->GetAction().GetTsi() == actionTsi && obj->GetAction().GetPgci() == actionPgci) {
 			for (int i = 0; i < obj->GetObjectParamsCount(); i++) {
 				MenuObjectParam* param = obj->GetObjectParam(i);
-				if (param->type == _T("image"))
+				if (param->type == _T("image")) {
+					PgcArray& pgcs = dvd->GetPgcArray(actionTsi == -2 ? m_tsi : actionTsi, false);
+					wxString uri;
+					if (actionPgci < (int)pgcs.size() && pgcs[actionPgci]->GetVobs().size() > 0)
+						uri = pgcs[actionPgci]->GetVobs()[0]->GetVideoFrameUri(obj->GetAction().GetChapter());
 					obj->SetParam(param->name, uri);
+				}
 			}
 		}
 	}
