@@ -3,7 +3,7 @@
 // Purpose:     DVD menu button properties dialog
 // Author:      Alex Thuering
 // Created:	20.11.2003
-// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.33 2009/12/30 17:46:21 ntalex Exp $
+// RCS-ID:      $Id: MenuObjectPropDlg.cpp,v 1.36 2010/04/28 07:34:26 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -314,7 +314,7 @@ void MenuObjectPropDlg::FillTargets(wxChoice* ctrl) {
 				if (tsi == m_tsi && pgci == m_pgci)
 					continue; // current menu
 				Pgc* pgc = ts->GetMenus()[pgci];
-				if (!m_dvd->IsJumppadsEnabled() && m_tsi != tsi && pgci > 0 && pgc->GetEntry().length() == 0)
+				if (!m_dvd->IsJumppadsEnabled() && m_tsi != tsi && pgci > 0 && pgc->GetEntries().size() == 0)
 					break; // cannot jump to specific menu from other titleset, only to an entry
 				wxString label = _("menu") + wxString::Format(wxT(" %d"), pgci + 1);
 				if (m_dvd->GetTitlesets().Count() > 1)
@@ -481,6 +481,12 @@ bool MenuObjectPropDlg::SetValues() {
 			GetTitle(), wxOK|wxICON_ERROR, this);
 			return false;
 		}
+		if (GetBool(4)) {
+			DVDAction action(m_object->GetAction());
+			action.SetCustom(GetString(5));
+			if (!action.IsValid(m_dvd, m_tsi, m_pgci, true, m_object->GetId(), true, false))
+				return false;
+		}
 	}
 	
 	int n = 0;
@@ -492,9 +498,10 @@ bool MenuObjectPropDlg::SetValues() {
 		action.SetPgci(GetSelectedTsi() != m_tsi || GetSelectedPgci() != m_pgci || !IsSelectedMenu() ? GetSelectedPgci() : -1);
 		action.SetMenu(IsSelectedMenu());
 		if (GetSelectedTsi() != m_tsi && IsSelectedMenu() && GetSelectedPgci() > 0) {
-			wxString entries = m_dvd->GetPgcArray(GetSelectedTsi(), true)[GetSelectedPgci()]->GetEntry();
-			action.SetEntry(entries.BeforeFirst(wxT(',')));
-		}
+			const StringSet& entries = m_dvd->GetPgcArray(GetSelectedTsi(), true)[GetSelectedPgci()]->GetEntries();
+			action.SetEntry(entries.size() > 0 ? *entries.begin() : wxT(""));
+		} else
+			action.SetEntry(wxT(""));
 		action.SetChapter(GetSelectedChapter());
 		n += 3;
 		action.SetPlayAll(GetBool(n++));
