@@ -3,7 +3,7 @@
 // Purpose:     Progress of generation/burning dialog
 // Author:      Alex Thuering
 // Created:     14.08.2004
-// RCS-ID:      $Id: ProgressDlg.cpp,v 1.90 2010/03/16 21:01:26 ntalex Exp $
+// RCS-ID:      $Id: ProgressDlg.cpp,v 1.94 2010/05/22 14:14:09 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -21,6 +21,7 @@
 #include <wx/file.h>
 #include <wx/regex.h>
 #include <wx/utils.h>
+#include <wx/platinfo.h>
 #include <wxSVG/SVGDocument.h>
 #include <wxSVG/mediadec_ffmpeg.h>
 
@@ -224,6 +225,7 @@ ProgressDlg::ProgressDlg(wxWindow* parent, Cache* cache, bool autoStart): wxDial
     do_layout();
     // end wxGlade
     m_cancel = false;
+    m_end = false;
     m_subStepCount = 0;
     m_cache = cache;
     m_autoStart = autoStart;
@@ -284,7 +286,10 @@ void ProgressDlg::OnHideDetails(wxCommandEvent& WXUNUSED(event)) {
 	}
 }
 
-void ProgressDlg::OnMinimize(wxCommandEvent& WXUNUSED(event)) {
+void ProgressDlg::OnMinimize(wxCommandEvent& event) {
+	wxPlatformInfo info;
+	if ((info.GetOperatingSystemId() & wxOS_WINDOWS) && !info.CheckOSVersion(6,0))
+		MakeModal(false);
 	((wxFrame*) GetParent())->Iconize();
 }
 
@@ -310,6 +315,7 @@ void ProgressDlg::AddDetailText(const wxString& text) {
 	m_detailsText->ShowPosition(m_detailsText->GetLastPosition());
 	if (wxLog::GetActiveTarget()->GetVerbose())
 		fprintf(stderr, "%s", (const char*) text.mb_str());
+	wxYieldIfNeeded();
 }
 
 void ProgressDlg::UpdateGauge() {
@@ -328,7 +334,7 @@ void ProgressDlg::OnCancel(wxCommandEvent& WXUNUSED(event)) {
 		AddSummaryMsg(_("Aborted"), wxEmptyString, *wxRED);
 		End();
 	} else
-		EndModal(wxID_OK);
+		m_end = true;
 }
 
 void ProgressDlg::End() {
@@ -342,8 +348,8 @@ bool ProgressDlg::IsCanceled() {
 }
 
 bool ProgressDlg::Start(BurnDlg* burnDlg, DVD* dvd) {
-	// disable window and redirect log messages into progress dialog details area
-	m_winDisabler = new wxWindowDisabler(this);
+	// disable parent window
+	MakeModal();
 	wxLog* previousLog = wxLog::SetActiveTarget(new ProgressDlgLog(this));
 	// show dialog
 	Show();
@@ -352,16 +358,16 @@ bool ProgressDlg::Start(BurnDlg* burnDlg, DVD* dvd) {
 	bool isOk = !IsCanceled();
 	// end
 	End();
-	// restore log and enable window
+	// restore log
 	delete wxLog::SetActiveTarget(previousLog);
-	delete m_winDisabler;
-	m_winDisabler = NULL;
 	// close the Window or release the controls
-	if (m_autoStart)
+	if (m_autoStart) {
 		Close(true);
-    else
-    	ShowModal();
-	
+	} else {
+    	while (!m_end)
+    		wxYield();
+    }
+	MakeModal(false);
 	return isOk;
 }
 
@@ -810,7 +816,7 @@ bool ProgressDlg::CreateIsoImage(BurnDlg* burnDlg, DVD* dvd, const wxString& dvd
 		wxString cmd = s_config.GetIsoSizeCmd();
 		cmd.Replace(_T("$DIR"), dvdOutDir.Mid(0, dvdOutDir.length() - 1));
 #ifdef __WXMSW__
-		cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + _T("..") + wxString(wxFILE_SEP_PATH) + _T("dvdauthor") + wxString(wxFILE_SEP_PATH) + cmd;
+		cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + cmd;
 #endif
 		wxArrayString output;
 		wxExecute(cmd, output, wxEXEC_SYNC | wxEXEC_NODISABLE);
@@ -898,7 +904,7 @@ bool ProgressDlg::BurnDvd(BurnDlg* burnDlg, DVD* dvd, const wxString& dvdOutDir,
 	wxString cmd = s_config.GetBurnScanCmd();
 	cmd.Replace(_T("$DEVICE"), burnDlg->GetDevice());
 #ifdef __WXMSW__
-	cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + _T("..") + wxString(wxFILE_SEP_PATH) + _T("dvdauthor") + wxString(wxFILE_SEP_PATH) + cmd;
+	cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + cmd;
 #endif
 	wxArrayString output;
 	while (true) {
@@ -930,7 +936,7 @@ bool ProgressDlg::BurnDvd(BurnDlg* burnDlg, DVD* dvd, const wxString& dvdOutDir,
 		cmd = s_config.GetIsoSizeCmd();
 		cmd.Replace(_T("$DIR"), dvdOutDir.Mid(0, dvdOutDir.length() - 1));
 #ifdef __WXMSW__
-		cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + _T("..") + wxString(wxFILE_SEP_PATH) + _T("dvdauthor") + wxString(wxFILE_SEP_PATH) + cmd;
+		cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + cmd;
 #endif
 		wxArrayString output;
 		wxExecute(cmd, output, wxEXEC_SYNC | wxEXEC_NODISABLE);
@@ -1126,8 +1132,6 @@ bool ProgressDlg::GenerateMenu(Menu* menu, const wxString& menuFile,
 
 	// convert jpeg to mpeg
 	AddDetailMsg(_("Create menu mpeg"));
-	if (s_config.GetMenuFrameCount()<25)
-		s_config.SetMenuFrameCount(25);
 	if (s_config.GetMenuVideoBitrate()<1000)
 		s_config.SetMenuVideoBitrate(1000);
 
