@@ -3,7 +3,7 @@
 // Purpose:     DVD title properties dialog
 // Author:      Alex Thuering
 // Created:     31.01.2004
-// RCS-ID:      $Id: TitlePropDlg.h,v 1.13 2009/12/30 17:49:22 ntalex Exp $
+// RCS-ID:      $Id: TitlePropDlg.h,v 1.15 2010/04/18 15:47:04 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -24,7 +24,9 @@ public:
 private:
 	DVD* m_dvd;
 	int m_tsi;
+	int m_pgci;
 	wxArrayString* m_audioLangCodes;
+	wxArrayString* m_subtitleLangCodes;
 	Video* m_video;
 	Pgc* m_pgc;
 	Vob* m_vob;
@@ -33,6 +35,7 @@ private:
 	wxCheckBox* m_doNotTranscodeCheckBox;
 	wxButton* m_addBt;
 	wxButton* m_delBt;
+	wxButton* m_propBt;
 	void CreatePropPanel(wxSizer* sizer);
 	bool SetValues();
 	void CreateButtonPane(wxSizer* sizer, bool resetButton = false, bool dontShowCheckbox = false);
@@ -41,6 +44,7 @@ private:
 	void OnSelectItem(wxCommandEvent& event);
 	void OnAddBt(wxCommandEvent& event);
 	void OnRemoveBt(wxCommandEvent& event);
+	void OnPropBt(wxCommandEvent& event);
 	void OnAV(wxCommandEvent& event);
 	void OnDoNotTranscodeCheck(wxCommandEvent& event);
 	void UpdateDoNotTranscodeCheck();
