@@ -3,7 +3,7 @@
 // Purpose:     Titleset Manager
 // Author:      Alex Thuering
 // Created:	27.01.2003
-// RCS-ID:      $Id: TitlesetManager.cpp,v 1.39 2010/01/12 20:47:35 ntalex Exp $
+// RCS-ID:      $Id: TitlesetManager.cpp,v 1.41 2010/05/09 18:19:22 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -450,7 +450,7 @@ bool TitlesetManager::AddVideo(const wxString& fname, bool createTitle, int tsi)
 		pgc->SetPostCommands(_T("call vmgm menu 1;"));
 		pgc->GetVobs().Add(vob);
 		pgcs.Add(pgc);
-		m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1, vob->GetVideoFrameUri(-1));
+		m_dvd->UpdateButtonImageFor(tsi, pgcs.GetCount() - 1);
 	} else
 		pgc->GetVobs().Add(vob);
 	
@@ -659,6 +659,8 @@ void TitlesetManager::OnMoveTitleLeft(wxCommandEvent& WXUNUSED(event)) {
 		SelectMenu(tsi, pgci-1);
 	UpdateItems();
 	SendDvdChangedEvent();
+	m_dvd->UpdateButtonImageFor(tsi, pgci - 1);
+	m_dvd->UpdateButtonImageFor(tsi, pgci);
 }
 
 void TitlesetManager::OnMoveTitleRight(wxCommandEvent& WXUNUSED(event)) {
@@ -678,6 +680,8 @@ void TitlesetManager::OnMoveTitleRight(wxCommandEvent& WXUNUSED(event)) {
 		SelectMenu(tsi, pgci+1);
 	UpdateItems();
 	SendDvdChangedEvent();
+	m_dvd->UpdateButtonImageFor(tsi, pgci);
+	m_dvd->UpdateButtonImageFor(tsi, pgci + 1);
 }
 
 void TitlesetManager::OnMoveTitleLeftUpdateUI(wxUpdateUIEvent& event) {
@@ -778,10 +782,7 @@ void TitlesetManager::OnDelete(wxCommandEvent& WXUNUSED(event)) {
 			delete pgc;
 			ts->GetTitles().RemoveAt(pgci);
 			for (unsigned int pgci2 = pgci; pgci2 <= ts->GetTitles().GetCount(); pgci2++) {
-				wxString uri;
-				if (pgci2 < ts->GetTitles().GetCount() && ts->GetTitles()[pgci2]->GetVobs().GetCount() > 0)
-					uri = ts->GetTitles()[pgci2]->GetVobs()[0]->GetVideoFrameUri(-1);
-				m_dvd->UpdateButtonImageFor(tsi, pgci2, uri);
+				m_dvd->UpdateButtonImageFor(tsi, pgci2);
 			}
 		}
 		// remove titleset if need
@@ -813,8 +814,11 @@ void TitlesetManager::OnProps(wxCommandEvent& WXUNUSED(event)) {
 		}
 	} else { //title
 		TitlePropDlg propDlg(this->GetParent(), m_dvd, tsi, pgci, vobi);
-		if (propDlg.ShowModal() == wxID_OK)
+		if (propDlg.ShowModal() == wxID_OK) {
+			m_dvd->UpdateButtonImageFor(tsi, pgci);
+			SendMenuSelectedEvent(); // updated MenuEditor
 			SendDvdChangedEvent();
+		}
 	}
 	m_pointed = -1;
 	Refresh();
