@@ -3,13 +3,14 @@
 // Purpose:     The list box to display information about streams in given VOB
 // Author:      Alex Thuering
 // Created:     03.05.2009
-// RCS-ID:      $Id: VobListBox.cpp,v 1.8 2010/01/03 20:47:20 ntalex Exp $
+// RCS-ID:      $Id: VobListBox.cpp,v 1.10 2010/04/10 09:22:58 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
 
 #include "VobListBox.h"
 #include "Config.h"
+#include "SubtitlePropDlg.h"
 #include <wx/filedlg.h>
 #include <wx/arrimpl.cpp>
 #include <wxSVG/mediadec_ffmpeg.h>
@@ -22,13 +23,18 @@ WX_DEFINE_OBJARRAY(RectList);
 WX_DEFINE_OBJARRAY(RectListOfList);
 WX_DEFINE_OBJARRAY(StringListOfList);
 
+BEGIN_EVENT_TABLE(VobListBox, wxVListBox)
+	EVT_LEFT_DCLICK(VobListBox::OnDoubleClick)
+END_EVENT_TABLE()
+
 const int ITEM_HEIGHT = 50;
 #define ITEM_FONT wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT)
 
-VobListBox::VobListBox(wxWindow* parent, wxWindowID id, Vob* vob, wxArrayString audioLangCodes, DVD* dvd):
-		wxVListBox(parent, id) {
-	m_vob = new Vob(*vob);
+VobListBox::VobListBox(wxWindow* parent, wxWindowID id, Vob* vob, wxArrayString audioLangCodes,
+		wxArrayString subtitleLangCodes, DVD* dvd): wxVListBox(parent, id) {
+	m_vob = vob;
 	m_audioLangCodes = audioLangCodes;
+	m_subtitleLangCodes = subtitleLangCodes;
 	m_dvd = dvd;
 	m_videoImg = Scale(LoadFrame(m_vob->GetFilename()));
 	m_audioImg = Scale(wxBITMAP_FROM_MEMORY(audio).ConvertToImage());
@@ -130,9 +136,10 @@ void VobListBox::RefreshInfo() {
 				break;
 			}
 		}
-		itemY += y + 1;
+		itemY += y > ITEM_HEIGHT ? y + 1 : ITEM_HEIGHT + 1;
 	}
 
+	m_subtitleChoiceIdx = m_choiceList.size();
 	for (unsigned int si = 0; si < m_vob->GetSubtitles().size(); si++) {
 		m_info.Add(wxArrayString());
 		m_infoRect.Add(RectList());
@@ -145,15 +152,21 @@ void VobListBox::RefreshInfo() {
 		
 		// filename
 		y = AddInfo(m_vob->GetSubtitles()[si]->GetFilename(), n, dc, x, y);
-		y = AddInfo(_("Subtitle:") + wxString(wxT(" "))
-				+ m_vob->GetSubtitles()[si]->GetFilename().AfterLast(wxT('.')), n, dc, x, y);
+		y = AddInfo(_("Subtitle:") + wxString(wxT(" ")) + m_vob->GetSubtitles()[si]->GetFilename().AfterLast(wxT('.')),
+				n, dc, x, y);
+
+		int langIdx = DVD::GetAudioLanguageCodes().Index(si < m_subtitleLangCodes.GetCount()
+				? m_subtitleLangCodes[si] : s_config.GetDefSubtitleLanguage());
+		wxRect& rect = m_infoRect[n][m_infoRect[n].size()-1];
+		y += AddChoiceCtrl(DVD::GetAudioLanguageCodes(), langIdx, rect, itemY, choiceIdx, true);
+		itemY += y > ITEM_HEIGHT ? y + 1 : ITEM_HEIGHT + 1;
 	}
 }
 
 int VobListBox::AddInfo(const wxString& s, int n, wxDC& dc, int x, int y) {
 	m_info[n].Add(s);
-	long w;
-	long h;
+	wxCoord w;
+	wxCoord h;
 	dc.GetTextExtent(s, &w, &h);
 	m_infoRect[n].Add(wxRect(x, y, w, h));
 	return y + h + 2;
@@ -210,7 +223,13 @@ wxBitmap VobListBox::Scale(wxImage image) {
 void VobListBox::RemoveItem(int index) {
 	if (index > (int)m_vob->GetAudioFilenames().size()) {
 		// remove subtitle
-		m_vob->GetSubtitles().RemoveAt(index - 1 - m_vob->GetAudioFilenames().size());
+		int subtitleIdx = index - 1 - m_vob->GetAudioFilenames().size();
+		m_vob->GetSubtitles().RemoveAt(subtitleIdx);
+		m_subtitleLangCodes.RemoveAt(subtitleIdx);
+		// choice index = count of video stream + count of audio streams * 2 + count of audio subtitle streams
+		int choiceIdx = 1 + m_vob->GetAudioStreamCount()*2 + subtitleIdx;
+		m_choiceList[choiceIdx]->Hide();
+		m_choiceList.RemoveAt(choiceIdx);
 	} else {
 		// removed audio file
 		m_vob->RemoveAudioFile(index-1);
@@ -244,6 +263,7 @@ void VobListBox::AddAudio(wxString filename) {
 
 void VobListBox::AddSubtitle(wxString filename) {
 	m_vob->GetSubtitles().Add(new TextSub(filename));
+	m_subtitleLangCodes.Add(s_config.GetDefSubtitleLanguage());
 	// update list box
 	RefreshInfo();
 	RefreshAll();
@@ -295,5 +315,25 @@ Vob* VobListBox::UpdateVob() {
 			break;
 		}
 	}
+	m_subtitleLangCodes.clear();
+	for (unsigned int si = 0; si < m_vob->GetSubtitles().size(); si++) {
+		m_subtitleLangCodes.Add(m_choiceList[choiceIdx++]->GetStringSelection());
+	}
 	return m_vob;
 }
+
+/**
+ * Processes a double click event
+ */
+void VobListBox::OnDoubleClick(wxMouseEvent& evt) {
+	if (GetSelection() >= 1 + (int) m_vob->GetAudioFilenames().GetCount()) {
+		UpdateVob();
+		int idx = GetSelection() - 1 - m_vob->GetAudioFilenames().GetCount();
+		TextSub* textsub = m_vob->GetSubtitles()[idx];
+		SubtitlePropDlg dialog(this, textsub, &m_subtitleLangCodes[idx]);
+		if (dialog.ShowModal() == wxID_OK) {
+			// update subtitle language choice
+			// TODO use m_subtitleChoiceIdx
+		}
+	}
+}
