@@ -3,7 +3,7 @@
 // Purpose:     DVD Authoring Application
 // Author:      Alex Thuering
 // Created:	10.10.2003
-// RCS-ID:      $Id: dvdstyler.cpp,v 1.42 2010/02/22 22:47:18 ntalex Exp $
+// RCS-ID:      $Id: dvdstyler.cpp,v 1.44 2010/05/22 14:13:38 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -50,17 +50,19 @@ bool DVDStyler::OnInit() {
 	if (version.length() < 3 || version.Mid(0, 3) != APP_VERSION.Mid(0, 3)) {
 		wxLogNull log;
 		s_config.SetVersion(APP_VERSION);
-		if (version.length() >= 3 && version.Mid(0, 3) == wxT("1.5")) {
+		if (version.Mid(0, 3) == wxT("1.7")) {
 			s_config.DeleteGroup(_T("Generate"));
-		} else if (version.Mid(0, 3) != wxT("1.7")) {
+		} else if (version.length() < 3 || version.Mid(0, 3) == wxT("1.5") || version.Mid(0, 3) == wxT("1.6")) {
 			s_config.DeleteGroup(_T("Generate"));
 			s_config.DeleteGroup(_T("Preview"));
 			s_config.DeleteGroup(_T("Iso"));
 			s_config.DeleteGroup(_T("Burn"));
 		}
 		s_config.Flush();
-	} else if (version != APP_VERSION)
+	} else if (version != APP_VERSION) {
 		s_config.SetVersion(APP_VERSION);
+		s_config.Flush();
+	}
 
 	wxInitAllImageHandlers();
 	// load new jpeg handler (with scale option)
@@ -149,6 +151,13 @@ bool DVDStyler::OnInit() {
 		wxString filename = parser.GetParam(i);
 		if (i == 0 && (filename.Lower().EndsWith(wxT(".xml")) || filename.Lower().EndsWith(wxT(".dvds")))) { 
 			mainWin->Open(filename);
+		} else if (i == 0 && filename.Lower().EndsWith(wxT(".dvdt"))) {
+			VideoFormat vf = (VideoFormat) s_config.GetDefVideoFormat();
+			AudioFormat af = (AudioFormat) s_config.GetDefAudioFormat();
+			AspectRatio ar = (AspectRatio) s_config.GetDefAspectRatio();
+			DiscCapacity dc = (DiscCapacity) s_config.GetDefDiscCapacity();
+			mainWin->NewDVD(filename, wxT(""), s_config.GetDefDiscLabel(), dc, s_config.GetVideoBitrate(),
+					vf <= vfCOPY ? vfPAL : vf, af <= afCOPY ? afMP2 : af, ar <= arAUTO ? ar4_3 : ar);
 		} else {
 			wxFfmpegMediaDecoder decoder;
 			if (decoder.Load(filename))
