@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Transcoder
 // Author:      Alex Thuering
 // Created:     26.04.2008
-// RCS-ID:      $Id: mediatrc_ffmpeg.cpp,v 1.21 2010/01/24 18:56:06 ntalex Exp $
+// RCS-ID:      $Id: mediatrc_ffmpeg.cpp,v 1.22 2010/05/03 06:06:48 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -500,12 +500,12 @@ bool wxFfmpegMediaTranscoder::AddVideoStream(AVFormatContext *oc,
 	AVCodecContext *video_enc;
 
 	CodecID codecId = videoFormat == vfNONE ? CODEC_ID_NONE : CODEC_ID_MPEG2VIDEO;
-	bool ntsc = videoFormat == vfNTSC ? true : false;
-
-	frame_width = 720;
-	frame_height = ntsc ? 480 : 576;
-	frame_rate.num = ntsc ? 30000 : 25;
-	frame_rate.den = ntsc ? 1001 : 1;
+	
+	wxSize frameSize = GetFrameSize(videoFormat);
+	frame_width = frameSize.GetWidth();
+	frame_height = frameSize.GetHeight();
+	frame_rate.num = isNTSC(videoFormat) ? 30000 : 25;
+	frame_rate.den = isNTSC(videoFormat) ? 1001 : 1;
 
 	st = av_new_stream(oc, oc->nb_streams);
 	if (!st) {
@@ -547,7 +547,7 @@ bool wxFfmpegMediaTranscoder::AddVideoStream(AVFormatContext *oc,
 		
 		output_codecs[nb_ocodecs] = codec;
 		
-		av_set_int(video_enc, "gop", ntsc ? 15 : 12);
+		av_set_int(video_enc, "gop", isNTSC(videoFormat) ? 15 : 12);
 		av_set_int(video_enc, "b", bitrate * 1000);
 		av_set_int(video_enc, "maxrate", vbr ? 9000000 : bitrate * 1000);
 		av_set_int(video_enc, "minrate", vbr ? 0 : bitrate * 1000);
