@@ -3,7 +3,7 @@
 // Purpose:     Pipe execute
 // Author:      Alex Thuering
 // Created:     23.08.2004
-// RCS-ID:      $Id: PipeExecute.cpp,v 1.4 2005/11/28 09:22:12 ntalex Exp $
+// RCS-ID:      $Id: PipeExecute.cpp,v 1.5 2010/04/05 16:17:04 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -268,9 +268,7 @@ bool wxPipeExecute::Execute(wxString command,
     wxString cmd = cmds[i];
 #ifdef __WXMSW__
     if (cmd.BeforeFirst(wxT(' ')).Find(wxT(':')) == -1)
-      cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + _T("..") +
-        wxString(wxFILE_SEP_PATH) + _T("dvdauthor") +
-        wxString(wxFILE_SEP_PATH) + cmd;
+      cmd = wxGetAppPath() + wxString(wxFILE_SEP_PATH) + cmd;
 #endif
     pid[i] = wxExecute(cmd, wxEXEC_ASYNC, proc[i]);
     if (pid[i]<=0)
