@@ -3,7 +3,7 @@
 // Purpose:     Properties dialog (base class for all properties dialogs)
 // Author:      Alex Thuering
 // Created:     18.11.2003
-// RCS-ID:      $Id: PropDlg.cpp,v 1.19 2009/10/20 19:58:03 ntalex Exp $
+// RCS-ID:      $Id: PropDlg.cpp,v 1.21 2010/04/04 10:13:24 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -16,6 +16,10 @@
 #include <wx/grid.h>
 #include <wx/spinctrl.h>
 #include <wx/statline.h>
+#include <wx/bmpcbox.h>
+
+#include <wx/arrimpl.cpp>
+WX_DEFINE_OBJARRAY(BitmapArray);
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////// ColourPanel ////////////////////////////////////
@@ -113,6 +117,7 @@ enum PropertyType {
   propSTAT_TEXT,
   propSPIN,
   propCOMBO,
+  propBITMAP_COMBO,
   propCHOICE,
   propCHECK,
   propRADIO,
@@ -390,17 +395,16 @@ wxSizer* wxPropDlg::AddComboProp(wxSizer* sizer, const wxString& label, const wx
 	if (!sizer) { // only update value
 		wxComboBox* ctrl = (wxComboBox*)m_controls[m_updateIndex];
 		ctrl->Clear();
-		SetComboData(ctrl, value, choices);
+		ctrl->Append(choices);
+		ctrl->SetStringSelection(value);
 		m_updateIndex++;
 		return NULL;
 	}
 	// add combobox control
 	if (label.length())
 		sizer->Add(new wxStaticText(propWindow, -1, label), 0, wxALIGN_CENTER_VERTICAL);
-	wxString strings[1];
-	wxComboBox* ctrl = new wxComboBox(propWindow, id, value,
-		wxDefaultPosition, wxDefaultSize, 0, strings, style);
-	SetComboData(ctrl, value, choices);
+	wxComboBox* ctrl = new wxComboBox(propWindow, id, value, wxDefaultPosition, wxDefaultSize, choices, style);
+	ctrl->SetStringSelection(value);
 	wxBoxSizer* pane = NULL;
 	if (width > 0) {
 		pane = new wxBoxSizer(wxHORIZONTAL);
@@ -416,18 +420,38 @@ wxSizer* wxPropDlg::AddComboProp(wxSizer* sizer, const wxString& label, const wx
 	return pane;
 }
 
-void wxPropDlg::SetComboData(wxComboBox* ctrl, const wxString& value,
-  const wxArrayString& choices)
-{
-  int sel = -1;
-  for (int i=0; i<(int)choices.GetCount(); i++)
-  {
-	ctrl->Append(choices[i]);
-	if (choices[i] == value)
-	  sel = i;
-  }
-  ctrl->SetSelection(sel);
-  ctrl->SetValue(value);
+wxSizer* wxPropDlg::AddBitmapComboProp(wxSizer* sizer, const wxString& label, const wxString& value,
+		const wxArrayString& choices, const BitmapArray& bitmaps, long style, int width, bool addSpacer, int id) {
+	if (!sizer) { // only update value
+		wxBitmapComboBox* ctrl = (wxBitmapComboBox*)m_controls[m_updateIndex];
+		ctrl->Clear();
+		for (unsigned int i = 0; i < choices.size(); i ++)
+			ctrl->Append(choices[i], bitmaps[i]);
+		ctrl->SetStringSelection(value);
+		m_updateIndex++;
+		return NULL;
+	}
+	// add combobox control
+	if (label.length())
+		sizer->Add(new wxStaticText(propWindow, -1, label), 0, wxALIGN_CENTER_VERTICAL);
+	wxBitmapComboBox* ctrl =
+		new wxBitmapComboBox(propWindow, id, value, wxDefaultPosition, wxDefaultSize, choices, style);
+	for (unsigned int i = 0; i < bitmaps.size(); i ++)
+		ctrl->SetItemBitmap(i, bitmaps[i]);
+	ctrl->SetStringSelection(value);
+	wxBoxSizer* pane = NULL;
+	if (width > 0) {
+		pane = new wxBoxSizer(wxHORIZONTAL);
+		pane->Add(ctrl);
+		if (addSpacer)
+			pane->Add(10, 10, 1, wxEXPAND);
+		sizer->Add(pane, 1, wxEXPAND, 0);
+	} else
+		sizer->Add(ctrl, 1, wxEXPAND, 0);
+	m_types.Add(propBITMAP_COMBO);
+	m_controls.Add(ctrl);
+	m_groupIds.Add(m_currGroupId);
+	return pane;
 }
 
 wxSizer* wxPropDlg::AddChoiceProp(wxSizer* sizer, const wxString& label, const wxString& value,
@@ -879,6 +903,8 @@ int wxPropDlg::GetInt(int index)
       return ((wxSpinCtrl*)m_controls[index])->GetValue();
     case propCOMBO:
       return ((wxComboBox*)m_controls[index])->GetSelection();
+    case propBITMAP_COMBO:
+      return ((wxBitmapComboBox*)m_controls[index])->GetSelection();
 	case propCHOICE:
       return ((wxChoice*)m_controls[index])->GetSelection();
     case propRADIO_GROUP:
