@@ -3,7 +3,7 @@
 // Purpose:     Base class for property dialogs
 // Author:      Alex Thuering
 // Created:     18.11.2003
-// RCS-ID:      $Id: PropDlg.h,v 1.17 2010/02/22 20:19:08 ntalex Exp $
+// RCS-ID:      $Id: PropDlg.h,v 1.18 2010/04/03 21:45:53 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -16,6 +16,8 @@
 #include <wx/dynarray.h>
 #include <wx/filedlg.h>
 
+WX_DECLARE_OBJARRAY(wxBitmap, BitmapArray);
+
 /** Base class for property dialogs.
   * Allow you to simply create properties dialogs without any GUI designer.
   * Using this class, you can also create dynamic property dialog.
@@ -94,10 +96,14 @@ protected:
 	 * Creates label and combobox.
 	 * @returns subSizer if width > 0, null otherwise
 	 */
-	wxSizer* AddComboProp(wxSizer* sizer, const wxString& label, const wxString& value,
-	  const wxArrayString& choices, long style = 0, int width = -1, bool addSpacer = true,
-	  int id = -1);
-	void SetComboData(wxComboBox* ctrl, const wxString& value, const wxArrayString& choices);
+	wxSizer* AddComboProp(wxSizer* sizer, const wxString& label, const wxString& value, const wxArrayString& choices,
+			long style = 0, int width = -1, bool addSpacer = true, int id = -1);
+	/**
+	 * Creates label and bitmap combobox.
+	 * @returns subSizer if width > 0, null otherwise
+	 */
+	wxSizer* AddBitmapComboProp(wxSizer* sizer, const wxString& label, const wxString& value, const wxArrayString& choices,
+			const BitmapArray& bitmaps, long style = 0, int width = -1, bool addSpacer = true, int id = -1);
 	/**
 	 * Creates label and choice control.
 	 * @returns subSizer if width > 0, null otherwise
